@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -468,14 +468,12 @@ typedef struct {
 #define k_CiscoV9FirstSwitched		22
 #define k_CiscoV9OutBytes		23
 #define k_CiscoV9OutPkts		24
-
-/* ... */
-
+#define k_CiscoV9MinPktLen		25
+#define k_CiscoV9MaxPktLen		26
 #define k_CiscoV9IpV6SrcAddr		27
 #define k_CiscoV9IpV6DstAddr		28
 #define k_CiscoV9IPv6SrcMask		29
 #define k_CiscoV9IpV6DstMask		30
-
 #define k_CiscoV9IpV6FlowLabel		31
 #define k_CiscoV9IpV6IcmpType		32
 #define k_CiscoV9IpV6MulIgmpType	33
@@ -499,17 +497,16 @@ typedef struct {
 
 /* ... */
 
+#define k_CiscoV9MinTtl			52
+#define k_CiscoV9MaxTtl			53
+#define k_CiscoV9IPv4IpId		54
 #define k_CiscoV9DstTos			55
 #define k_CiscoV9SrcMac			56
 #define k_CiscoV9DstMac			57
 #define k_CiscoV9SrcVlan		58
 #define k_CiscoV9DstVlan		59
-
 #define k_CiscoV9IpProtocolVersion	60
 #define k_CiscoV9Direction		61
-
-/* ... */
-
 #define k_CiscoV9IpV6NextHop		62
 #define k_CiscoV9BgpIpV6NextHop		63
 #define k_CiscoV9IpV6OptionHeaders	64
@@ -526,6 +523,60 @@ typedef struct {
 #define k_CiscoV9MplsLabel8		77
 #define k_CiscoV9MplsLabel9		78
 #define k_CiscoV9MplsLabel10		79
+#define k_CiscoV9InDstMac		80
+#define k_CiscoV9OutSrcMac		81
+#define k_CiscoV9IfName			82
+#define k_CiscoV9IfDesc			83
+#define k_CiscoV9SampleName		84
+#define k_CiscoV9InPermanentBytes	85
+#define k_CiscoV9InPermanentPkts	86
+
+/* ... */
+
+#define k_CiscoV9FragmentOffset		88
+#define k_CiscoV9ForwardingStatus	89
+
+#define k_CiscoV9MplsPalRD		90
+#define k_CiscoV9MplsPrefixLen		91
+#define k_CiscoV9SrcTrafficIndex	92
+#define k_CiscoV9DstTrafficIndex	93
+#define k_CiscoV9ApplicationDesc	94
+#define k_CiscoV9ApplicationTag		95
+#define k_CiscoV9ApplicationName	96
+
+/* ... */
+
+#define k_CiscoV9PostDSCP		98
+#define k_CiscoV9MulticastReplication	99
+
+/* ... */
+
+#define k_CiscoV9ConnId			148
+
+/* ... */
+
+#define k_CiscoV9IcmpType		176
+#define k_CiscoV9IcmpCode		177
+#define k_CiscoV9IcmpTypeV6		178
+#define k_CiscoV9IcmpCodeV6		179
+
+/* ... */
+
+#define k_CiscoV9NatInsideGlobalAddr	225
+#define k_CiscoV9NatOutsideGlobalAddr	226
+#define k_CiscoV9postNatL4SrcPort	227
+#define k_CiscoV9postNatL4DstPort	228
+#define k_CiscoV9postNatEvent		230
+
+/* ... */
+
+#define k_CiscoV9IngressVRFID		234
+
+/* ... */
+
+#define k_CiscoEventTimeMilliSec	323
+#define k_CiscoEventTimeMicroSec	324
+#define k_CiscoEventTimeNanoSec		325
 
 
 #endif  /* _FlowPDU_H_ */
