@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_client.h#3 $
- * $DateTime: 2012/06/15 10:05:41 $
- * $Change: 2423 $
+ * $Id: //depot/argus/clients/include/argus_client.h#70 $
+ * $DateTime: 2014/05/22 14:57:43 $
+ * $Change: 2837 $
  */
 
 
@@ -131,7 +131,7 @@ extern "C" {
 
 
 #define TSEQ_HASHSIZE		9029
-#define HASHNAMESIZE		4096
+#define HASHNAMESIZE		8192
 
 #define RASIGLENGTH		32
    
@@ -139,7 +139,7 @@ extern "C" {
 #define RA_SRV_LEFT		1
 #define RA_SRV_RIGHT		2
     
-#define ARGUSMAXSIGFILE		2048
+#define ARGUSMAXSIGFILE		0x80000
 #define RA_SRC_SERVICES		0
 #define RA_DST_SERVICES		1
  
@@ -147,7 +147,8 @@ extern "C" {
 
 
 
-typedef struct ArgusRecord * (*ArgusNetFlowHandler)(struct ArgusInput *, uint8_t **);
+typedef struct ArgusRecord * (*ArgusNetFlowHandler)(struct ArgusParserStruct *, struct ArgusInput *, uint8_t **, int *);
+
 
 struct ArgusInput {
    struct ArgusQueueHeader qhdr;
@@ -173,6 +174,8 @@ struct ArgusInput {
    long long ostart, ostop;
    unsigned short portnum;
    char *hostname, *filename, *servname;
+   char *user, *pass;
+
    FILE *file, *pipe;
    unsigned int ArgusLocalNet, ArgusNetMask;
    unsigned int ArgusID, ArgusIDType;
@@ -199,7 +202,8 @@ struct ArgusInput {
 
    struct ArgusCanonRecord  ArgusGenerateRecordCanonBuf;
    struct ArgusRecordStruct ArgusGenerateRecordStructBuf;
-   char ArgusGenerateRecordLabelBuf[MAXSTRLEN];
+
+   char ArgusGenerateRecordLabelBuf[MAXBUFFERLEN];
 
    char ArgusOriginalBuffer[MAXARGUSRECORD];
 
@@ -534,6 +538,7 @@ enum Aggregation
 };
 #endif
 
+
 typedef struct {
     uint16_t format;             /* Header format, it is 2 in this round */
     char    newline;            /* Newline character, '\n' */
@@ -1037,7 +1042,7 @@ typedef struct {
 #endif /* __NFC_DATAFILE_H__ */
 
 
-#if defined(HAVE_SOLARIS)
+#if defined(ARGUS_SOLARIS)
 #include <sys/socket.h>
 #endif
 
@@ -1209,8 +1214,8 @@ int ArgusInsertRecord (struct ArgusParserStruct *, struct RaBinProcessStruct *,
 void ArgusCalculatePeriod (struct ArgusRecordStruct *, struct ArgusAdjustStruct *);
 
 void ArgusAdjustTransactions (struct ArgusRecordStruct *, double, double);
-void ArgusAdjustSrcLoss (struct ArgusRecordStruct *, double);
-void ArgusAdjustDstLoss (struct ArgusRecordStruct *, double);
+void ArgusAdjustSrcLoss (struct ArgusRecordStruct *, struct ArgusRecordStruct *, double);
+void ArgusAdjustDstLoss (struct ArgusRecordStruct *, struct ArgusRecordStruct *, double);
 
 int ArgusReadSflowStreamSocket (struct ArgusParserStruct *, struct ArgusInput *);
 int ArgusReadSflowDatagramSocket (struct ArgusParserStruct *, struct ArgusInput *);
@@ -1364,8 +1369,8 @@ extern struct ArgusRecordStruct *ArgusAlignRecord(struct ArgusParserStruct *, st
 extern int ArgusInsertRecord (struct ArgusParserStruct *, struct RaBinProcessStruct *, struct ArgusRecordStruct *, int);
 extern void ArgusCalculatePeriod (struct ArgusRecordStruct *, struct ArgusAdjustStruct *);
 
-extern void ArgusAdjustSrcLoss (struct ArgusRecordStruct *, double);
-extern void ArgusAdjustDstLoss (struct ArgusRecordStruct *, double);
+extern void ArgusAdjustSrcLoss (struct ArgusRecordStruct *, struct ArgusRecordStruct *, double);
+extern void ArgusAdjustDstLoss (struct ArgusRecordStruct *, struct ArgusRecordStruct *, double);
 
 extern int ArgusReadCiscoStreamSocket (struct ArgusParserStruct *, struct ArgusInput *);
 extern int ArgusReadCiscoDatagramSocket (struct ArgusParserStruct *, struct ArgusInput *);
