@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_cluster.h#2 $
- * $DateTime: 2012/06/15 10:05:41 $
- * $Change: 2423 $
+ * $Id: //depot/argus/clients/include/argus_cluster.h#36 $
+ * $DateTime: 2014/05/27 19:38:58 $
+ * $Change: 2838 $
  */
 
 #ifndef ArgusCluster_h
@@ -32,7 +32,11 @@
 extern "C" {
 #endif
 
+#if defined(ARGUS_PCRE)
+#include "pcreposix.h"
+#else
 #include <regex.h>
+#endif
 
 struct RaFlowModelStruct {
    char *desc;  
@@ -62,6 +66,9 @@ struct ArgusIPAddrStruct {
 
 #define ARGUS_AGGREGATOR_DIRTY	1
 #define ARGUS_CREATE_AUTOID	2
+
+#define ARGUS_RECORD_AGGREGATOR	1
+#define ARGUS_OBJ_AGGREGATOR	2
  
 struct ArgusAggregatorStruct {
    struct ArgusAggregatorStruct *nxt;
@@ -97,7 +104,7 @@ struct ArgusAggregatorStruct {
    struct nff_program filter;
 
    char *modelstr;
-
+   char *grepstr;
    char *labelstr;
    regex_t lpreg;
 
@@ -1059,13 +1066,13 @@ struct ArgusMaskStruct ArgusIsisPsnpMaskDefs[ARGUS_MAX_MASK_LIST] = {
    {"doui",  3, ARGUS_MAC_INDEX,        4,  3, 1},
 };
 
-struct ArgusAggregatorStruct *ArgusNewAggregator (struct ArgusParserStruct *, char *);
+struct ArgusAggregatorStruct *ArgusNewAggregator (struct ArgusParserStruct *, char *, int type);
 struct ArgusAggregatorStruct *ArgusCopyAggregator (struct ArgusAggregatorStruct *);
 void ArgusDeleteAggregator (struct ArgusParserStruct *, struct ArgusAggregatorStruct *);
 struct RaPolicyStruct *RaFlowModelOverRides(struct ArgusAggregatorStruct *, struct ArgusRecordStruct *);
 void ArgusGenerateNewFlow(struct ArgusAggregatorStruct *, struct ArgusRecordStruct *);
  
-unsigned int ArgusMergeAddress(unsigned int *, unsigned int *, int, int, char *);
+unsigned int ArgusMergeAddress(unsigned int *, unsigned int *, int, int, unsigned char *);
 void ArgusMergeRecords (struct ArgusAggregatorStruct *, struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 void ArgusIntersectRecords (struct ArgusAggregatorStruct *, struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 
@@ -1080,13 +1087,13 @@ extern struct ArgusMaskStruct ArgusIpV6RevMaskDefs[ARGUS_MAX_MASK_LIST];
 extern struct ArgusMaskStruct ArgusEtherRevMaskDefs[ARGUS_MAX_MASK_LIST];
 extern struct ArgusMaskStruct ArgusArpRevMaskDefs[ARGUS_MAX_MASK_LIST];
 
-extern struct ArgusAggregatorStruct *ArgusNewAggregator (struct ArgusParserStruct *, char *);
+extern struct ArgusAggregatorStruct *ArgusNewAggregator (struct ArgusParserStruct *, char *, int type);
 extern struct ArgusAggregatorStruct *ArgusCopyAggregator (struct ArgusAggregatorStruct *);
 extern void ArgusDeleteAggregator (struct ArgusParserStruct *, struct ArgusAggregatorStruct *);
 extern struct RaPolicyStruct *RaFlowModelOverRides(struct ArgusAggregatorStruct *, struct ArgusRecordStruct *);
 extern void ArgusGenerateNewFlow(struct ArgusAggregatorStruct *, struct ArgusRecordStruct *);
  
-extern unsigned int ArgusMergeAddress(unsigned int *, unsigned int *, int, int, char *);
+extern unsigned int ArgusMergeAddress(unsigned int *, unsigned int *, int, int, unsigned char *);
 extern void ArgusMergeRecords (struct ArgusAggregatorStruct *, struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern void ArgusIntersectRecords (struct ArgusAggregatorStruct *, struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 
