@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_def.h#1 $
- * $DateTime: 2012/04/17 12:22:02 $
- * $Change: 2368 $
+ * $Id: //depot/argus/clients/include/argus_def.h#52 $
+ * $DateTime: 2014/05/12 10:49:40 $
+ * $Change: 2818 $
  */
 
 /* Argus_def.h */
@@ -148,6 +148,7 @@ extern "C" {
 #define ARGUS_EVENT				0x40   /* New Argus Event/Message Record */
 #define ARGUS_DATASUP				0x50   /* New Supplemental Argus Data Record */
 #define ARGUS_ARCHIVAL				0x60   /* New Archival Argus Data Record */
+#define ARGUS_VFLOW   				0x70   /* Pluribus Vflow Record Type*/
 
 
 /*
@@ -259,7 +260,8 @@ extern "C" {
 
 
 #define MAXARGUSRECORD           		0x40000
-#define MAXSTRLEN               		4096
+#define MAXBUFFERLEN               		0x10000
+#define MAXSTRLEN               		0x1000
 
 
 /* Argus Data 
@@ -1622,6 +1624,7 @@ extern "C" {
 #define ARGUS_MULTIPATH                  0x03
 #define ARGUS_SRC_MULTIPATH              0x01
 #define ARGUS_DST_MULTIPATH              0x02
+#define ARGUS_PORT_INDEX                 0x04
 
 /* Jitter Transport DSR Type */
 #define ARGUS_JITTER_DSR                 0x46
@@ -1702,6 +1705,7 @@ extern "C" {
 
 /* Argus Label SubTypes */
 #define ARGUS_SVC_LABEL                 0x01
+#define ARGUS_PROC_LABEL                0x04
 
 /* Argus ASN DSR */
 #define ARGUS_ASN_DSR                   0x32
