@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,15 +20,19 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_grep.h#1 $
- * $DateTime: 2012/04/17 12:22:02 $
- * $Change: 2368 $
+ * $Id: //depot/argus/clients/include/argus_grep.h#8 $
+ * $DateTime: 2014/05/12 10:49:40 $
+ * $Change: 2818 $
  */
 
 
 #ifndef ArgusGrep_h
 #define ArgusGrep_h
 
+#if defined(ARGUS_PCRE)
+#include <pcreposix.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
