@@ -1,6 +1,6 @@
 /*
  * Argus Software Common include files -  output structures
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /*
- * $Id: //depot/argus-3.0.6/clients/include/argus_isis.h#2 $
- * $DateTime: 2012/05/09 10:17:30 $
- * $Change: 2405 $
+ * $Id: //depot/argus/clients/include/argus_isis.h#9 $
+ * $DateTime: 2014/05/12 10:49:40 $
+ * $Change: 2818 $
  */
 
 #ifndef ArgusIsis_h
@@ -33,7 +33,7 @@ extern "C" {
 #endif
 
 #include <sys/time.h>
-#if defined(HAVE_SOLARIS) || defined(CYGWIN)
+#if defined(ARGUS_SOLARIS) || defined(CYGWIN)
 #include <net/etherdefs.h>
 #endif
 #include <argus_ethertype.h>
@@ -65,6 +65,9 @@ extern "C" {
  * complete IS-IS support.
  */
 
+#if !defined(ETHER_ADDR_LEN)
+#define ETHER_ADDR_LEN		6
+#endif
 
 #define NLPID_CLNS	129	/* 0x81 */
 #define NLPID_ISIS	131	/* 0x83 */
