@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_out.h#1 $
- * $DateTime: 2012/04/17 12:22:02 $
- * $Change: 2368 $
+ * $Id: //depot/argus/clients/include/argus_out.h#54 $
+ * $DateTime: 2014/05/12 10:49:40 $
+ * $Change: 2818 $
  */
 
 
@@ -33,7 +33,7 @@
 extern "C" {
 #endif
 
-#if defined(HAVE_SOLARIS) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(ARGUS_SOLARIS) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <net/if.h>
@@ -176,6 +176,15 @@ static inline unsigned int ArgusDSRLen(struct ArgusDSRHeader *dsr,
   }
 }
 
+struct ArgusIdStruct {
+   int status;
+   char name[64];
+};
+
+struct ArgusInputStruct {
+   struct ArgusDSRHeader hdr;
+   struct ArgusIdStruct id;
+};
 
 struct ArgusMarStruct {
    unsigned int status, argusid;
@@ -195,6 +204,12 @@ struct ArgusMarStruct {
    unsigned int thisid, record_len;
 };
 
+struct ArgusMarSupStruct {
+   unsigned int status, argusid;
+   struct ArgusTime startime, now;
+   struct ArgusInputStruct input;
+};
+
 struct ArgusICMPObject {
    unsigned char icmp_type, icmp_code;
    unsigned short iseq;
@@ -887,7 +902,6 @@ struct ArgusLabelStruct {
    }l_un;
 };
 
-
 /*
    The ArgusRecordHeader is composed of 4 4-bit fields, the
    type, version, cause and options fields.  For the purpose
@@ -939,6 +953,18 @@ struct ArgusEventStruct {
    struct ArgusDataStruct       data;
 };
 
+#if defined ARGUS_PLURIBUS
+
+#include <nvc_client.h>
+
+struct ArgusVflowStruct {
+   struct ArgusDSRHeader         hdr;   /* immediate data */
+   struct ArgusTransportStruct trans;
+   struct ArgusEventTimeStruct  time;
+   nvc_vflow_stat_t            vflow;
+};
+#endif
+
 
 struct ArgusFarStruct {
    struct ArgusFlow flow;
@@ -949,8 +975,12 @@ struct ArgusRecord {
    struct ArgusRecordHeader hdr;
    union {
       struct ArgusMarStruct     mar;
+      struct ArgusMarSupStruct  sup;
       struct ArgusFarStruct     far;
       struct ArgusEventStruct event;
+//#if defined ARGUS_PLURIBUS
+//    struct ArgusVflowStruct vflow;
+//#endif
    } ar_un;
 };
 
