@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2014 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_sort.h#1 $
- * $DateTime: 2012/04/17 12:22:02 $
- * $Change: 2368 $
+ * $Id: //depot/argus/clients/include/argus_sort.h#37 $
+ * $DateTime: 2014/05/12 10:49:40 $
+ * $Change: 2818 $
  */
 
 #ifndef ArgusSort_h
@@ -32,8 +32,8 @@
 extern "C" {
 #endif
 
-#define ARGUS_MAX_SORT_ALG		67
-#define MAX_SORT_ALG_TYPES		67
+#define ARGUS_MAX_SORT_ALG		75
+#define MAX_SORT_ALG_TYPES		75
 
 struct ArgusSortRecord {
    struct ArgusQueueHeader qhdr;
@@ -118,7 +118,16 @@ struct ArgusSorterStruct {
 #define ARGUSSORTIDLETIME   		64
 #define ARGUSSORTSRCOUI        		65
 #define ARGUSSORTDSTOUI        		66
+#define ARGUSSORTAPPBYTES        	67
+#define ARGUSSORTSRCAPPBYTES        	68
+#define ARGUSSORTDSTAPPBYTES        	69
+#define ARGUSSORTAPPBYTERATIO        	70
+#define ARGUSSORTINODE	        	71
  
+#define ARGUSSORTSRCGAP	        	72
+#define ARGUSSORTDSTGAP	        	73
+#define ARGUSSORTSRCDUP	        	74
+#define ARGUSSORTDSTDUP	        	75
 
 #if defined(ArgusSort)
 
@@ -146,6 +155,7 @@ int ArgusSortSrcMac (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortDstMac (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortSrcAddr (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortDstAddr (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+int ArgusSortInode (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortProtocol (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortSrcMpls (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortDstMpls (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
@@ -177,6 +187,13 @@ int ArgusSortSeq (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortByteCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortSrcByteCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortDstByteCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+
+int ArgusSortAppByteRatio (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+
+int ArgusSortAppByteCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+int ArgusSortAppSrcByteCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+int ArgusSortAppDstByteCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+
 int ArgusSortPktsCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortSrcPktsCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortDstPktsCount (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
@@ -202,6 +219,14 @@ int ArgusSortSum (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortSrcOui (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 int ArgusSortDstOui (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 
+int ArgusSortSrcGap (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+int ArgusSortDstGap (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+
+/*
+int ArgusSortSrcDup (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+int ArgusSortDstDup (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+*/
+
 int (*ArgusSortAlgorithmTable[MAX_SORT_ALG_TYPES])(struct ArgusRecordStruct *, struct ArgusRecordStruct *) = {
    ArgusSortStartTime,
    ArgusSortStartTime,
@@ -224,9 +249,11 @@ int (*ArgusSortAlgorithmTable[MAX_SORT_ALG_TYPES])(struct ArgusRecordStruct *, s
    ArgusSortDstTos,
    ArgusSortSrcTtl,
    ArgusSortDstTtl,
+
    ArgusSortByteCount,
    ArgusSortSrcByteCount,
    ArgusSortDstByteCount,
+
    ArgusSortPktsCount,
    ArgusSortSrcPktsCount,
    ArgusSortDstPktsCount,
@@ -270,6 +297,15 @@ int (*ArgusSortAlgorithmTable[MAX_SORT_ALG_TYPES])(struct ArgusRecordStruct *, s
    ArgusSortIdleTime,
    ArgusSortSrcOui,
    ArgusSortDstOui,
+
+   ArgusSortAppByteCount,
+   ArgusSortSrcAppByteCount,
+   ArgusSortDstAppByteCount,
+   ArgusSortAppByteRatio,
+   ArgusSortAppByteRatio,
+   ArgusSortInode,
+   ArgusSortSrcGap,
+   ArgusSortDstGap,
 };
 
 char *ArgusSortKeyWords[MAX_SORT_ALG_TYPES] = {
@@ -340,6 +376,14 @@ char *ArgusSortKeyWords[MAX_SORT_ALG_TYPES] = {
    "idle",
    "soui",
    "doui",
+   "appbytes",
+   "sappbytes",
+   "dappbytes",
+   "abr",
+   "pcr",
+   "inode",
+   "sgap",
+   "dgap",
 };
 
 #else
@@ -366,6 +410,7 @@ extern int ArgusSortMin (struct ArgusRecordStruct *, struct ArgusRecordStruct *)
 extern int ArgusSortMax (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern int ArgusSortSrcAddr (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern int ArgusSortDstAddr (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+extern int ArgusSortInode (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern int ArgusSortProtocol (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern int ArgusSortIpId (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern int ArgusSortSrcPort (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
@@ -398,6 +443,11 @@ extern int ArgusSortTcpRtt (struct ArgusRecordStruct *, struct ArgusRecordStruct
 extern int ArgusSortSrcOui (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern int ArgusSortDstOui (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 
+extern int ArgusSortSrcGap (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+extern int ArgusSortDstGap (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+extern int ArgusSortSrcDup (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+extern int ArgusSortDstDup (struct ArgusRecordStruct *, struct ArgusRecordStruct *);
+
 extern int (*ArgusSortAlgorithmTable[MAX_SORT_ALG_TYPES])(struct ArgusRecordStruct *, struct ArgusRecordStruct *);
 extern char *ArgusSortKeyWords[MAX_SORT_ALG_TYPES];
 #endif
