@@ -1,7 +1,7 @@
 #!/bin/bash
 #
 #  Argus Client Support Software.  Tools to support tools for Argus data.
-#  Copyright (C) 2000-2012 QoSient, LLC.
+#  Copyright (C) 2000-2014 QoSient, LLC.
 #  All Rights Reserved
 #
 #  ragetcountrycodes.sh
@@ -16,12 +16,12 @@
 #  Carter Bullard <carter@qosient.com>
 #
 
-wget --passive-ftp ftp://ftp.afrinic.net/pub/stats/afrinic/delegated-afrinic-latest
-wget --passive-ftp ftp://ftp.apnic.net/pub/stats/apnic/delegated-apnic-latest
-wget --passive-ftp ftp://ftp.arin.net/pub/stats/arin/delegated-arin-latest
-wget --passive-ftp ftp://ftp.lacnic.net/pub/stats/lacnic/delegated-lacnic-latest
-wget --passive-ftp ftp://ftp.ripe.net/ripe/stats/delegated-ripencc-latest
-wget --passive-ftp ftp://ftp.apnic.net/pub/stats/iana/delegated-iana-latest
+wget http://ftp.apnic.net/stats/arin/delegated-arin-extended-latest
+wget http://ftp.apnic.net/stats/afrinic/delegated-afrinic-latest
+wget http://ftp.apnic.net/stats/apnic/delegated-apnic-latest
+wget http://ftp.apnic.net/stats/lacnic/delegated-lacnic-latest
+wget http://ftp.apnic.net/stats/ripe-ncc/delegated-ripencc-latest
+wget http://ftp.apnic.net/stats/iana/delegated-iana-latest
 
 fgrep ipv4 delegated-[alr]*-latest delegated-iana-latest > delegated-ipv4-latest
 rm delegated-[alr]*-latest delegated-iana-latest
